@@ -8,6 +8,10 @@ class _View(object):
         self._views_directory = f"{os.path.abspath('')}/resources/views"
         self._templates = Jinja2Templates(directory=self.views_directory)
 
+    @property
+    def templates(self):
+        return self._templates
+
     @property
     def views_directory(self):
         return self._views_directory
